@@ -1,12 +1,35 @@
-from __future__ import annotations
-
 from collections import defaultdict
 from dataclasses import dataclass
-from string import Template
-from typing import TYPE_CHECKING, Any, List, Mapping, Optional, Tuple, Union, cast
+from string import Template as StringTemplate
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    List,
+    Mapping,
+    Optional,
+    Tuple,
+    Union,
+    cast,
+)
 
-from robotcode.core.dataclasses import as_dict, from_dict
-from robotcode.core.logging import LoggingDescriptor
+from robot.parsing.lexer.tokens import Token
+from robot.parsing.model.blocks import Keyword, TestCase, VariableSection
+from robot.parsing.model.statements import (
+    Arguments,
+    Documentation,
+    Fixture,
+    KeywordCall,
+    KeywordName,
+    Statement,
+    Template,
+    TestCaseName,
+    TestTemplate,
+    Variable,
+)
+from robot.utils.escaping import split_from_equals
+from robot.variables.search import contains_variable
+
+from robotcode.core.language import language_id
 from robotcode.core.lsp.types import (
     AnnotatedTextEdit,
     ChangeAnnotation,
@@ -22,15 +45,14 @@ from robotcode.core.lsp.types import (
     TextDocumentEdit,
     WorkspaceEdit,
 )
+from robotcode.core.text_document import TextDocument
+from robotcode.core.utils.dataclasses import as_dict, from_dict
 from robotcode.core.utils.inspect import iter_methods
-
-from ...common.decorators import code_action_kinds, language_id
-from ...common.text_document import TextDocument
-from ..diagnostics.errors import DIAGNOSTICS_SOURCE_NAME, Error
-from ..diagnostics.model_helper import ModelHelperMixin
-from ..utils.ast_utils import (
+from robotcode.core.utils.logging import LoggingDescriptor
+from robotcode.robot.diagnostics.errors import DIAGNOSTICS_SOURCE_NAME, Error
+from robotcode.robot.diagnostics.model_helper import ModelHelper
+from robotcode.robot.utils.ast import (
     FirstAndLastRealStatementFinder,
-    Token,
     get_node_at_position,
     get_nodes_at_position,
     get_tokens_at_position,
@@ -38,6 +60,8 @@ from ..utils.ast_utils import (
     range_from_node,
     range_from_token,
 )
+
+from ...common.decorators import code_action_kinds
 from .code_action_helper_mixin import (
     SHOW_DOCUMENT_SELECT_AND_RENAME_COMMAND,
     CodeActionDataBase,
@@ -55,7 +79,7 @@ class CodeActionData(CodeActionDataBase):
     diagnostics_code: Optional[Union[int, str]] = None
 
 
-KEYWORD_WITH_ARGS_TEMPLATE = Template(
+KEYWORD_WITH_ARGS_TEMPLATE = StringTemplate(
     """\
 ${name}
     [Arguments]    ${args}
@@ -64,7 +88,7 @@ ${name}
 """
 )
 
-KEYWORD_TEMPLATE = Template(
+KEYWORD_TEMPLATE = StringTemplate(
     """\
 ${name}
     # TODO: implement keyword "${name}".
@@ -73,10 +97,10 @@ ${name}
 )
 
 
-class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin, CodeActionHelperMixin):
+class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, ModelHelper, CodeActionHelperMixin):
     _logger = LoggingDescriptor()
 
-    def __init__(self, parent: RobotLanguageServerProtocol) -> None:
+    def __init__(self, parent: "RobotLanguageServerProtocol") -> None:
         super().__init__(parent)
 
         parent.code_action.collect.add(self.collect)
@@ -86,48 +110,53 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
     @language_id("robotframework")
     @code_action_kinds([CodeActionKind.QUICK_FIX])
-    async def collect(
-        self, sender: Any, document: TextDocument, range: Range, context: CodeActionContext
+    def collect(
+        self,
+        sender: Any,
+        document: TextDocument,
+        range: Range,
+        context: CodeActionContext,
     ) -> Optional[List[Union[Command, CodeAction]]]:
         result = []
         for method in iter_methods(self, lambda m: m.__name__.startswith("code_action_")):
-            code_actions = await method(document, range, context)
+            code_actions = method(document, range, context)
             if code_actions:
                 result.extend(code_actions)
 
         if result:
-            return list(sorted(result, key=lambda ca: ca.title))
+            return sorted(result, key=lambda ca: ca.title)
 
         return None
 
-    async def resolve(self, sender: Any, code_action: CodeAction) -> Optional[CodeAction]:
+    def resolve(self, sender: Any, code_action: CodeAction) -> Optional[CodeAction]:
         if code_action.data is not None and isinstance(code_action.data, Mapping):
             type = code_action.data.get("type", None)
             if type == "quickfix":
                 method_name = code_action.data.get("method")
-                method = next(iter_methods(self, lambda m: m.__name__ == f"resolve_code_action_{method_name}"))
-                await method(code_action, data=from_dict(code_action.data, CodeActionData))
+                method = next(
+                    iter_methods(
+                        self,
+                        lambda m: m.__name__ == f"resolve_code_action_{method_name}",
+                    )
+                )
+                method(
+                    code_action,
+                    data=from_dict(code_action.data, CodeActionData),
+                )
 
         return None
 
-    async def code_action_create_keyword(
+    def code_action_create_keyword(
         self, document: TextDocument, range: Range, context: CodeActionContext
     ) -> Optional[List[Union[Command, CodeAction]]]:
-        from robot.parsing.model.statements import (
-            Fixture,
-            KeywordCall,
-            Template,
-            TestTemplate,
-        )
-
         result: List[Union[Command, CodeAction]] = []
 
         if (context.only and CodeActionKind.QUICK_FIX in context.only) or context.trigger_kind in [
             CodeActionTriggerKind.INVOKED,
             CodeActionTriggerKind.AUTOMATIC,
         ]:
-            model = await self.parent.documents_cache.get_model(document, False)
-            namespace = await self.parent.documents_cache.get_namespace(document)
+            model = self.parent.documents_cache.get_model(document, False)
+            namespace = self.parent.documents_cache.get_namespace(document)
 
             for diagnostic in (
                 d
@@ -135,7 +164,7 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
                 if d.source == DIAGNOSTICS_SOURCE_NAME and d.code == Error.KEYWORD_NOT_FOUND
             ):
                 disabled = None
-                node = await get_node_at_position(model, diagnostic.range.start)
+                node = get_node_at_position(model, diagnostic.range.start)
 
                 if isinstance(node, (KeywordCall, Fixture, TestTemplate, Template)):
                     tokens = get_tokens_at_position(node, diagnostic.range.start)
@@ -148,7 +177,10 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
                     if bdd_token is not None and token is not None:
                         keyword_token = token
 
-                    lib_entry, kw_namespace = await self.get_namespace_info_from_keyword_token(namespace, keyword_token)
+                    (
+                        lib_entry,
+                        kw_namespace,
+                    ) = self.get_namespace_info_from_keyword_token(namespace, keyword_token)
 
                     if lib_entry is not None and lib_entry.library_doc.type == "LIBRARY":
                         disabled = CodeActionDisabledType("Keyword is from a library")
@@ -166,7 +198,12 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
                             f"Create Keyword `{text}`",
                             kind=CodeActionKind.QUICK_FIX,
                             data=as_dict(
-                                CodeActionData("quickfix", "create_keyword", document.document_uri, diagnostic.range)
+                                CodeActionData(
+                                    "quickfix",
+                                    "create_keyword",
+                                    document.document_uri,
+                                    diagnostic.range,
+                                )
                             ),
                             diagnostics=[diagnostic],
                             disabled=disabled,
@@ -176,25 +213,13 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
         return result if result else None
 
-    async def resolve_code_action_create_keyword(
-        self, code_action: CodeAction, data: CodeActionData
-    ) -> Optional[CodeAction]:
-        from robot.parsing.lexer import Token as RobotToken
-        from robot.parsing.model.statements import (
-            Fixture,
-            KeywordCall,
-            Template,
-            TestTemplate,
-        )
-        from robot.utils.escaping import split_from_equals
-        from robot.variables.search import contains_variable
-
-        document = await self.parent.documents.get(data.document_uri)
+    def resolve_code_action_create_keyword(self, code_action: CodeAction, data: CodeActionData) -> Optional[CodeAction]:
+        document = self.parent.documents.get(data.document_uri)
         if document is None:
             return None
 
-        model = await self.parent.documents_cache.get_model(document, False)
-        node = await get_node_at_position(model, data.range.start)
+        model = self.parent.documents_cache.get_model(document, False)
+        node = get_node_at_position(model, data.range.start)
 
         if isinstance(node, (KeywordCall, Fixture, TestTemplate, Template)):
             tokens = get_tokens_at_position(node, data.range.start)
@@ -203,13 +228,16 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
             keyword_token = tokens[-1]
 
-            namespace = await self.parent.documents_cache.get_namespace(document)
+            namespace = self.parent.documents_cache.get_namespace(document)
 
             bdd_token, token = self.split_bdd_prefix(namespace, keyword_token)
             if bdd_token is not None and token is not None:
                 keyword_token = token
 
-            lib_entry, kw_namespace = await self.get_namespace_info_from_keyword_token(namespace, keyword_token)
+            (
+                lib_entry,
+                kw_namespace,
+            ) = self.get_namespace_info_from_keyword_token(namespace, keyword_token)
 
             if lib_entry is not None and lib_entry.library_doc.type == "LIBRARY":
                 return None
@@ -224,12 +252,12 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
             arguments = []
 
-            for t in node.get_tokens(RobotToken.ARGUMENT):
+            for t in node.get_tokens(Token.ARGUMENT):
                 name, value = split_from_equals(cast(Token, t).value)
                 if value is not None and not contains_variable(name, "$@&%"):
                     arguments.append(f"${{{name}}}")
                 else:
-                    arguments.append(f"${{arg{len(arguments)+1}}}")
+                    arguments.append(f"${{arg{len(arguments) + 1}}}")
 
             insert_text = (
                 KEYWORD_WITH_ARGS_TEMPLATE.substitute(name=text, args="    ".join(arguments))
@@ -238,11 +266,11 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
             )
 
             if lib_entry is not None and lib_entry.library_doc.type == "RESOURCE" and lib_entry.library_doc.source:
-                dest_document = await self.parent.documents.get_or_open_document(lib_entry.library_doc.source)
+                dest_document = self.parent.documents.get_or_open_document(lib_entry.library_doc.source)
             else:
                 dest_document = document
 
-            code_action.edit, select_range = await self._apply_create_keyword(dest_document, insert_text)
+            code_action.edit, select_range = self._apply_create_keyword(dest_document, insert_text)
 
             code_action.command = Command(
                 SHOW_DOCUMENT_SELECT_AND_RENAME_COMMAND,
@@ -253,13 +281,11 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
         return None
 
-    async def _apply_create_keyword(self, document: TextDocument, insert_text: str) -> Tuple[WorkspaceEdit, Range]:
-        model = await self.parent.documents_cache.get_model(document, False)
-        namespace = await self.parent.documents_cache.get_namespace(document)
+    def _apply_create_keyword(self, document: TextDocument, insert_text: str) -> Tuple[WorkspaceEdit, Range]:
+        model = self.parent.documents_cache.get_model(document, False)
+        namespace = self.parent.documents_cache.get_namespace(document)
 
-        insert_text, insert_range = await self.create_insert_keyword_workspace_edit(
-            document, model, namespace, insert_text
-        )
+        insert_text, insert_range = self.create_insert_keyword_workspace_edit(document, model, namespace, insert_text)
 
         we = WorkspaceEdit(
             document_changes=[
@@ -278,7 +304,7 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
         return we, selection_range
 
-    async def code_action_disable_robotcode_diagnostics_for_line(
+    def code_action_disable_robotcode_diagnostics_for_line(
         self, document: TextDocument, range: Range, context: CodeActionContext
     ) -> Optional[List[Union[Command, CodeAction]]]:
         if (
@@ -305,7 +331,11 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
                         kind=CodeActionKind.QUICK_FIX,
                         data=as_dict(
                             CodeActionData(
-                                "quickfix", "disable_robotcode_diagnostics_for_line", document.document_uri, range, k
+                                "quickfix",
+                                "disable_robotcode_diagnostics_for_line",
+                                document.document_uri,
+                                range,
+                                k,
                             )
                         ),
                         diagnostics=v,
@@ -315,11 +345,11 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
         return None
 
-    async def resolve_code_action_disable_robotcode_diagnostics_for_line(
+    def resolve_code_action_disable_robotcode_diagnostics_for_line(
         self, code_action: CodeAction, data: CodeActionData
     ) -> Optional[CodeAction]:
         if data.range.start.line == data.range.end.line and data.range.start.character <= data.range.end.character:
-            document = await self.parent.documents.get(data.document_uri)
+            document = self.parent.documents.get(data.document_uri)
             if document is None:
                 return None
 
@@ -338,7 +368,13 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
                 document_changes=[
                     TextDocumentEdit(
                         OptionalVersionedTextDocumentIdentifier(str(document.uri), document.version),
-                        [AnnotatedTextEdit("disable_robotcode_diagnostics_for_line", insert_range, insert_text)],
+                        [
+                            AnnotatedTextEdit(
+                                "disable_robotcode_diagnostics_for_line",
+                                insert_range,
+                                insert_text,
+                            )
+                        ],
                     )
                 ],
                 change_annotations={
@@ -352,12 +388,9 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
         return None
 
-    async def code_action_create_local_variable(
+    def code_action_create_local_variable(
         self, document: TextDocument, range: Range, context: CodeActionContext
     ) -> Optional[List[Union[Command, CodeAction]]]:
-        from robot.parsing.model.blocks import Keyword, TestCase
-        from robot.parsing.model.statements import Documentation, Fixture, Statement, Template, TestCaseName
-
         result: List[Union[Command, CodeAction]] = []
 
         if (context.only and CodeActionKind.QUICK_FIX in context.only) or context.trigger_kind in [
@@ -373,8 +406,8 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
                     diagnostic.range.start.line == diagnostic.range.end.line
                     and diagnostic.range.start.character < diagnostic.range.end.character
                 ):
-                    model = await self.parent.documents_cache.get_model(document, False)
-                    nodes = await get_nodes_at_position(model, range.start)
+                    model = self.parent.documents_cache.get_model(document, False)
+                    nodes = get_nodes_at_position(model, range.start)
 
                     if not any(n for n in nodes if isinstance(n, (Keyword, TestCase))):
                         continue
@@ -410,19 +443,16 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
         return result if result else None
 
-    async def resolve_code_action_create_local_variable(
+    def resolve_code_action_create_local_variable(
         self, code_action: CodeAction, data: CodeActionData
     ) -> Optional[CodeAction]:
-        from robot.parsing.model.blocks import Keyword, TestCase
-        from robot.parsing.model.statements import Documentation, Fixture, Statement, Template
-
         if data.range.start.line == data.range.end.line and data.range.start.character <= data.range.end.character:
-            document = await self.parent.documents.get(data.document_uri)
+            document = self.parent.documents.get(data.document_uri)
             if document is None:
                 return None
 
-            model = await self.parent.documents_cache.get_model(document, False)
-            nodes = await get_nodes_at_position(model, data.range.start)
+            model = self.parent.documents_cache.get_model(document, False)
+            nodes = get_nodes_at_position(model, data.range.start)
 
             if not any(n for n in nodes if isinstance(n, (Keyword, TestCase))):
                 return None
@@ -442,12 +472,21 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
             insert_text = f"{spaces}${{{text}}}    Set Variable    value\n"
             node_range = range_from_node(node)
-            insert_range = Range(start=Position(node_range.start.line, 0), end=Position(node_range.start.line, 0))
+            insert_range = Range(
+                start=Position(node_range.start.line, 0),
+                end=Position(node_range.start.line, 0),
+            )
             code_action.edit = WorkspaceEdit(
                 document_changes=[
                     TextDocumentEdit(
                         OptionalVersionedTextDocumentIdentifier(str(document.uri), document.version),
-                        [AnnotatedTextEdit("create_local_variable", insert_range, insert_text)],
+                        [
+                            AnnotatedTextEdit(
+                                "create_local_variable",
+                                insert_range,
+                                insert_text,
+                            )
+                        ],
                     )
                 ],
                 change_annotations={"create_local_variable": ChangeAnnotation("Create Local variable", False)},
@@ -465,7 +504,7 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
         return None
 
-    async def code_action_create_suite_variable(
+    def code_action_create_suite_variable(
         self, document: TextDocument, range: Range, context: CodeActionContext
     ) -> Optional[List[Union[Command, CodeAction]]]:
         result: List[Union[Command, CodeAction]] = []
@@ -507,19 +546,16 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
         return result if result else None
 
-    async def resolve_code_action_create_suite_variable(
+    def resolve_code_action_create_suite_variable(
         self, code_action: CodeAction, data: CodeActionData
     ) -> Optional[CodeAction]:
-        from robot.parsing.model.blocks import VariableSection
-        from robot.parsing.model.statements import Variable
-
         if data.range.start.line == data.range.end.line and data.range.start.character <= data.range.end.character:
-            document = await self.parent.documents.get(data.document_uri)
+            document = self.parent.documents.get(data.document_uri)
             if document is None:
                 return None
 
-            model = await self.parent.documents_cache.get_model(document, False)
-            nodes = await get_nodes_at_position(model, data.range.start)
+            model = self.parent.documents_cache.get_model(document, False)
+            nodes = get_nodes_at_position(model, data.range.start)
 
             node = nodes[-1] if nodes else None
 
@@ -531,7 +567,10 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
             if any(n for n in nodes if isinstance(n, (VariableSection))) and isinstance(node, Variable):
                 node_range = range_from_node(node)
-                insert_range = Range(start=Position(node_range.start.line, 0), end=Position(node_range.start.line, 0))
+                insert_range = Range(
+                    start=Position(node_range.start.line, 0),
+                    end=Position(node_range.start.line, 0),
+                )
             else:
                 finder = FindSectionsVisitor()
                 finder.visit(model)
@@ -540,11 +579,14 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
                     section = finder.variable_sections[-1]
 
                     _, last_stmt = FirstAndLastRealStatementFinder.find_from(section)
-                    end_lineno = last_stmt.end_lineno if last_stmt else section.end_lineno
+                    end_lineno = last_stmt.end_lineno if last_stmt else section.end_lineno  # type: ignore
                     if end_lineno is None:
                         return None
 
-                    insert_range = Range(start=Position(end_lineno, 0), end=Position(end_lineno, 0))
+                    insert_range = Range(
+                        start=Position(end_lineno, 0),
+                        end=Position(end_lineno, 0),
+                    )
                 else:
                     insert_range_prefix = "\n\n*** Variables ***\n"
                     if finder.setting_sections:
@@ -552,12 +594,18 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
                         insert_range_suffix = "\n\n"
                         section = finder.setting_sections[-1]
 
-                        _, last_stmt = FirstAndLastRealStatementFinder.find_from(section)
-                        end_lineno = last_stmt.end_lineno if last_stmt else section.end_lineno
+                        (
+                            _,
+                            last_stmt,
+                        ) = FirstAndLastRealStatementFinder.find_from(section)
+                        end_lineno = last_stmt.end_lineno if last_stmt else section.end_lineno  # type: ignore
                         if end_lineno is None:
                             return None
 
-                        insert_range = Range(start=Position(end_lineno, 0), end=Position(end_lineno, 0))
+                        insert_range = Range(
+                            start=Position(end_lineno, 0),
+                            end=Position(end_lineno, 0),
+                        )
                     else:
                         insert_range_prefix = "*** Variables ***\n"
                         insert_range_suffix = "\n\n"
@@ -578,7 +626,13 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
                 document_changes=[
                     TextDocumentEdit(
                         OptionalVersionedTextDocumentIdentifier(str(document.uri), document.version),
-                        [AnnotatedTextEdit("create_suite_variable", insert_range, insert_text)],
+                        [
+                            AnnotatedTextEdit(
+                                "create_suite_variable",
+                                insert_range,
+                                insert_text,
+                            )
+                        ],
                     )
                 ],
                 change_annotations={"create_suite_variable": ChangeAnnotation("Create suite variable", False)},
@@ -600,11 +654,9 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
             return code_action
         return None
 
-    async def code_action_add_argument(
+    def code_action_add_argument(
         self, document: TextDocument, range: Range, context: CodeActionContext
     ) -> Optional[List[Union[Command, CodeAction]]]:
-        from robot.parsing.model.blocks import Keyword
-
         result: List[Union[Command, CodeAction]] = []
 
         if (context.only and CodeActionKind.QUICK_FIX in context.only) or context.trigger_kind in [
@@ -627,8 +679,8 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
                     if not text:
                         continue
 
-                    model = await self.parent.documents_cache.get_model(document, False)
-                    nodes = await get_nodes_at_position(model, range.start)
+                    model = self.parent.documents_cache.get_model(document, False)
+                    nodes = get_nodes_at_position(model, range.start)
 
                     if not any(n for n in nodes if isinstance(n, Keyword)):
                         continue
@@ -651,15 +703,9 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
         return result if result else None
 
-    async def resolve_code_action_add_argument(
-        self, code_action: CodeAction, data: CodeActionData
-    ) -> Optional[CodeAction]:
-        from robot.parsing.lexer.tokens import Token
-        from robot.parsing.model.blocks import Keyword
-        from robot.parsing.model.statements import Arguments, Documentation, KeywordName, Statement
-
+    def resolve_code_action_add_argument(self, code_action: CodeAction, data: CodeActionData) -> Optional[CodeAction]:
         if data.range.start.line == data.range.end.line and data.range.start.character <= data.range.end.character:
-            document = await self.parent.documents.get(data.document_uri)
+            document = self.parent.documents.get(data.document_uri)
             if document is None:
                 return None
 
@@ -667,8 +713,8 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
             if not text:
                 return None
 
-            model = await self.parent.documents_cache.get_model(document, False)
-            nodes = await get_nodes_at_position(model, data.range.start)
+            model = self.parent.documents_cache.get_model(document, False)
+            nodes = get_nodes_at_position(model, data.range.start)
 
             keyword = next((n for n in nodes if isinstance(n, Keyword)), None)
             if keyword is None:
@@ -697,7 +743,10 @@ class RobotCodeActionQuickFixesProtocolPart(RobotLanguageServerProtocolPart, Mod
 
                 insert_text = f"{spaces}[Arguments]    ${{{text}}}=\n"
                 node_range = range_from_node(first_stmt)
-                insert_range = Range(start=Position(node_range.start.line, 0), end=Position(node_range.start.line, 0))
+                insert_range = Range(
+                    start=Position(node_range.start.line, 0),
+                    end=Position(node_range.start.line, 0),
+                )
             else:
                 insert_text = f"    ${{{text}}}="
                 argument_tokens = arguments.get_tokens(Token.ARGUMENT)
